@@ -258,7 +258,8 @@ class Connection(object):
         data = self._shooju_api.search_series(query, date_start, date_finish, size, query_size, fields)
         return self._process_search_response(data)
 
-    def scroll(self, query='', date_start=None, date_finish=None, fields=None, size=0):
+
+    def scroll(self, query='', date_start=None, date_finish=None, fields=None, size=0, query_size=2500):
         """
         Performs a scroll search. Function is a generator, it returns one series at a time
 
@@ -274,7 +275,7 @@ class Connection(object):
         :param size: number of points to retrieve per series
         """
 
-        r = self._shooju_api.search_series(query, date_start, date_finish, size, fields=fields, scroll=True, query_size=500)
+        r = self._shooju_api.search_series(query, date_start, date_finish, size, fields=fields, scroll=True, query_size=query_size)
         scroll_id = r['scroll_id']
 
         while True:
@@ -379,6 +380,15 @@ class Connection(object):
         """
         return self._shooju_api.delete_series(series_id)
 
+    def delete_by_query(self, query):
+        """
+        Permanently deletes all series that match the query - be careful
+
+        :param query: query to base the deletion on
+        :return: number of series deleted
+        """
+        return self._shooju_api.delete_series_by_query(query)
+
     def download_file(self, file_id, filename=None):
         """
         Downloads a file. If no `filename` is provided, a temporary file is created
@@ -597,6 +607,7 @@ class ShoojuApi(object):
     API_SERIES_BULK = '/series/bulk/'
     API_SERIES_BLOCK_SEARCH = '/series/block/search'
     API_SERIES_SCROLL = '/series/block/scroll'
+    API_SERIES_DELETE_BY_QUERY = '/series/delete'
     API_JOBS = '/jobs/'
     API_FILES = '/files/{id}/download'
     API_STATUS = '/status/detailed/'
@@ -663,6 +674,16 @@ class ShoojuApi(object):
         self.client.delete(self.API_SERIES_SINGLE, params=params)
         return True
 
+    def delete_series_by_query(self, query):
+        """
+        Permanently deletes all series that match the query - be careful
+
+        :param query: query to base the deletion on
+        :return: number of series deleted
+        """
+        return self.client.delete(self.API_SERIES_DELETE_BY_QUERY, data_json={'query': query})['deleted']
+
+
     def register_job(self, description, notes='', source='shooju'):
         """
         Registers a job in Shooju.
